# Fox-Cola-Tools

一个简单的 Python 工具库示例。

## 安装

```bash
    pip install fox-cola-tools
```



### Django settings 配置示例

你可以在 Django 的 `settings.py` 中设置以下变量：
```text
CUSTOM_KEY = "you CUSTOM_KEY"
CUSTOM_IV = "you CUSTOM_IV"
```